MultiSelectMenu --- Make multiple selections at one prompt
==========================================================

Bases: :class:`consolemenu.ConsoleMenu`

.. autoclass:: consolemenu.MultiSelectMenu
    :members:
